---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2010-07-02;110
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20100719&codiceRedaz=010G0132&dataVigenza=20251104
dataGU: 20100719
codiceRedaz: 010G0132
dataVigenza: 20251104
---

# Disposizioni in materia di atto pubblico informatico redatto dal notaio, a norma dell'articolo 65 della legge 18 giugno 2009, n. 69. (10G0132)

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76 e 87, quinto comma, della Costituzione;

Visto l'articolo 65 della legge 18 giugno 2009, n. 69, recante delega al Governo in materia di atto pubblico informatico redatto dal notaio;

Vista la legge 16 febbraio 1913, n. 89, recante ordinamento del notariato e degli archivi notarili;

Visto il regio decreto-legge 23 ottobre 1924, n. 1737, convertito dalla legge 18 marzo 1926, n. 562, recante norme complementari per l'attuazione del nuovo ordinamento degli archivi notarili;

Vista la legge 3 agosto 1949, n. 577, recante istituzione del Consiglio nazionale del notariato e modificazioni alle norme sull'amministrazione della Cassa nazionale del notariato;

Visto il decreto legislativo 7 marzo 2005, n. 82, recante codice dell'amministrazione digitale;

Vista la preliminare deliberazione del Consiglio dei Ministri, adottata nella riunione del 1° marzo 2010;

Acquisito il parere della competente Commissione della Camera dei deputati espresso in data 9 giugno 2010;

Rilevato che il Senato della Repubblica non ha espresso il parere nei termini;

Vista la deliberazione del Consiglio dei Ministri, adottata nella riunione del 24 giugno 2010;

Sulla proposta del Ministro della giustizia, di concerto con il Ministro dell'economia e delle finanze e con il Ministro per la pubblica amministrazione e l'innovazione;

Emana il seguente decreto legislativo:

## Art. 1. - Modifiche alla legge 16 febbraio 1913, n. 89

1. Alla legge 16 febbraio 1913, n. 89, sono apportate le seguenti modificazioni:

- a) dopo l'articolo 23 sono inseriti i seguenti: «Art. 23-bis. - 1. Il notaio per l'esercizio delle sue funzioni deve munirsi della firma digitale di cui all'articolo 1, comma 1, lettera s), del decreto legislativo 7 marzo 2005, n. 82, rilasciata dal Consiglio nazionale del notariato. 2. Le disposizioni di cui al comma 1 si applicano anche al coadiutore e al notaio delegato. Art. 23-ter. - 1. Il certificato qualificato, di cui all'articolo 1, comma 1, lettera f), del decreto legislativo 7 marzo 2005, n. 82, rilasciato al notaio per l'esercizio delle sue funzioni nel rispetto delle regole tecniche di cui all'articolo 34, commi 3 e 4, dello stesso decreto, attesta, sulla base delle comunicazioni inviate dai consigli notarili distrettuali, anche la sua iscrizione nel ruolo. 2. Le modalita' di gestione del certificato di cui al comma 1 devono comunque garantirne l'immediata sospensione o revoca, a richiesta dello stesso titolare o delle autorita' competenti, in tutti i casi previsti dalla normativa vigente in materia di firme elettroniche o quando il notaio e' sospeso o cessa dall'esercizio delle sue funzioni per qualsiasi causa, compreso il trasferimento ad altro distretto. 3. Il notaio custodisce ed utilizza personalmente, ai sensi dell'articolo 32 del decreto legislativo 7 marzo 2005, n. 82, il dispositivo di firma collegato al certificato di cui al comma 1.»;
- b) all'articolo 38 e' aggiunto, in fine, il seguente comma: «Il capo dell'archivio notarile, avuta notizia della morte del notaro, richiede al Consiglio nazionale del notariato il trasferimento immediato agli archivi notarili degli atti, dei registri e dei repertori dallo stesso conservati nella struttura di cui all'articolo 62-bis. Il Consiglio nazionale del notariato, accertato il corretto trasferimento dei dati, provvede alla loro cancellazione.»;
- c) dopo l'articolo 47 sono inseriti i seguenti: «Art. 47-bis. - 1. All'atto pubblico di cui all'articolo 2700 del codice civile, redatto con procedure informatiche si applicano le disposizioni della presente legge e quelle emanate in attuazione della stessa. 2. L'autenticazione di cui all'articolo 2703, secondo comma, del codice civile, e' regolata, in caso di utilizzo di modalita' informatiche, dall'articolo 25 del decreto legislativo 7 marzo 2005, n 82. Art. 47-ter. - 1. Le disposizioni per la formazione e la conservazione degli atti pubblici e delle scritture private autenticate si applicano, in quanto compatibili, anche ai documenti informatici di cui ai commi 1 e 2 dell'articolo 47-bis. 2. L'atto pubblico informatico e' ricevuto in conformita' a quanto previsto dall'articolo 47 ed e' letto dal notaio mediante l'uso e il controllo personale degli strumenti informatici. 3. Il notaio nell'atto pubblico e nell'autenticazione delle firme deve attestare anche la validita' dei certificati di firma eventualmente utilizzati dalle parti.»;
- d) dopo l'articolo 51 e' inserito il seguente: «Art. 52-bis. - 1. Le parti, i fidefacenti, l'interprete e i testimoni sottoscrivono personalmente l'atto pubblico informatico in presenza del notaio con firma digitale o con firma elettronica, consistente anche nell'acquisizione digitale della sottoscrizione autografa. 2. Il notaio appone personalmente la propria firma digitale dopo le parti, l'interprete e i testimoni e in loro presenza.»;
- e) dopo l'articolo 57 e' inserito il seguente: «Art. 57-bis. - 1. Quando deve essere allegato un documento redatto su supporto cartaceo ad un documento informatico, il notaio ne allega copia informatica, certificata conforme ai sensi dell'articolo 22, commi 1 e 3, del decreto legislativo 7 marzo 2005, n 82. 2. Quando un documento informatico deve essere allegato ad un atto pubblico o ad una scrittura privata da autenticare, redatti su supporto cartaceo, il notaio ne allega copia conforme ai sensi dell'articolo 23 del decreto legislativo 7 marzo 2005, n. 82, formata sullo stesso supporto.»;
- f) dopo l'articolo 59 e' inserito il seguente: «Art. 59-bis. - 1. Il notaio ha facolta' di rettificare, fatti salvi i diritti dei terzi, un atto pubblico o una scrittura privata autenticata, contenente errori od omissioni materiali relativi a dati preesistenti alla sua redazione, provvedendovi, anche ai fini dell'esecuzione della pubblicita', mediante propria certificazione contenuta in atto pubblico da lui formato.»;
- g) all'articolo 62, primo comma, la parola: «giornalmente» e' sostituita dalle seguenti: «entro il giorno successivo»;
- h) dopo l'articolo 62 sono inseriti i seguenti: «Art. 62-bis. - 1. Il notaio per la conservazione degli atti di cui agli articoli 61 e 72, terzo comma, se informatici, si avvale della struttura predisposta e gestita dal Consiglio nazionale del notariato nel rispetto dei principi di cui all'articolo 60 del decreto legislativo 7 marzo 2005, n. 82. Gli atti di cui agli articoli 61 e 72, terzo comma conservati nella suddetta struttura costituiscono ad ogni effetto di legge originali informatici da cui possono essere tratti duplicati e copie. 2. Il Consiglio nazionale del notariato svolge l'attivita' di cui al comma 1 nel rispetto dei principi di cui agli articoli 12 e 50 del decreto legislativo 7 marzo 2005, n. 82 e delle regole tecniche di cui all'articolo 71 dello stesso decreto e predispone strumenti tecnici idonei a consentire, nei soli casi previsti dalla legge, l'accesso ai documenti conservati nella struttura di cui al comma 1. 3. Le spese per il funzionamento della struttura sono poste a carico dei notai e sono ripartite secondo i criteri determinati dal Consiglio nazionale del notariato, escluso ogni onere per lo Stato. Art. 62-ter. - 1. Nella struttura di cui al comma 1 dell'articolo 62-bis il notaio conserva anche le copie informatiche degli atti rogati o autenticati su supporto cartaceo, con l'indicazione degli estremi delle annotazioni di cui all'articolo 23 del regio decreto-legge 23 ottobre 1924, n. 1737, convertito dalla legge 18 marzo 1926, n. 562. 2. Il notaio attesta la conformita' all'originale delle copie di cui al comma 1. Art. 62-quater. - 1. In caso di perdita degli atti, dei repertori e dei registri informatici, alla cui conservazione e tenuta e' obbligato il notaio, egli provvede a chiederne la ricostruzione con ricorso al presidente del tribunale competente, ai sensi del regio decreto-legge 15 novembre 1925, n. 2071. 2. La ricostruzione degli atti di cui al comma 1 puo' essere, altresi', richiesta da chiunque ne ha interesse. 3. Ai fini della ricostruzione possono essere utilizzate anche altre registrazioni informatiche conservate presso lo stesso notaio che ha formato l'atto ovvero presso pubblici registri ovvero, in mancanza, una copia autentica dello stesso da chiunque posseduta. 4. Non si fa luogo al procedimento di ricostruzione se e' disponibile una copia di sicurezza eseguita nell'ambito delle procedure di conservazione cui all'articolo 68-bis, comma 1.»;
- i) dopo l'articolo 66 sono inseriti i seguenti: «Art. 66-bis. - 1. Tutti i repertori e i registri dei quali e' obbligatoria la tenuta per il notaio sono formati e conservati su supporto informatico, nel rispetto dei principi di cui al decreto legislativo 7 marzo 2005, n. 82. 2. Il notaio provvede alla tenuta dei repertori e dei registri di cui al comma 1 avvalendosi della struttura di cui all'articolo 62-bis. 3. Con uno o piu' decreti non aventi natura regolamentare del Ministro della giustizia, di concerto con il Ministro dell'economia e delle finanze, il Ministro per i beni e le attivita' culturali, il Ministro per la pubblica amministrazione e l'innovazione e il Ministro per la semplificazione normativa, sentiti il Consiglio nazionale del notariato ed il Garante per la protezione dei dati personali e la DigitPA, sono determinate le regole tecniche per la formazione e la conservazione dei repertori, per il controllo periodico del repertorio di cui all'articolo 68 del decreto del Presidente della Repubblica 26 aprile 1986, n. 131, e per la ricerca nei repertori stessi delle annotazioni compiute dal notaio. Art. 66-ter. - 1. La tenuta del repertorio informatico, sostituisce gli indici previsti dall'articolo 62, comma sesto.»;
- l) all'articolo 67, primo comma, sono aggiunte, in fine le seguenti parole: «, ivi compresi quelli conservati presso la struttura di cui all'articolo 62-bis.»;
- m) dopo l'articolo 68 sono inseriti i seguenti: «Art. 68-bis. - 1. Con uno o piu' decreti non aventi natura regolamentare del Ministro della giustizia, di concerto con il Ministro dell'economia e delle finanze, il Ministro per la pubblica amministrazione e l'innovazione e il Ministro per la semplificazione normativa sentiti il Consiglio nazionale del notariato ed il Garante per la protezione dei dati personali e la DigitPA, sono determinate, nel rispetto delle disposizioni di cui al decreto legislativo 7 marzo 2005, n. 82: a) le tipologie di firma elettronica ulteriori rispetto a quella prevista dall'articolo 52-bis che possono essere utilizzate per la sottoscrizione dell'atto pubblico, ferma restando l'idoneita' dei dispositivi di cui all'articolo 1, comma 1, lettere q), r) e s), dello stesso decreto; b) le regole tecniche per l'organizzazione della struttura di cui al comma 1 dell'articolo 62-bis; c) le regole tecniche per la trasmissione telematica, la conservazione e la consultazione degli atti, delle copie e della documentazione di cui agli articoli 62-bis e 62-ter; d) le regole tecniche per il rilascio delle copie da parte del notaio di quanto previsto alla lettera c); e) le regole tecniche per l'esecuzione delle annotazioni previste dalla legge sugli atti di cui all'articolo 62-bis; f) le regole tecniche per l'esecuzione delle ispezioni di cui agli articoli da 127 a 134, per il trasferimento agli archivi notarili degli atti, dei registri e dei repertori formati su supporto informatico e per la loro conservazione dopo la cessazione del notaio dall'esercizio o il suo trasferimento in altro distretto. 2. Con decreto adottato ai sensi del comma 1 sono stabilite, anche al fine di garantire il rispetto della disposizione di cui all'articolo 476, primo comma, del codice di procedura civile, le regole tecniche per il rilascio su supporto informatico della copia esecutiva, di cui all'articolo 474 del codice di procedura civile. 3. Agli atti e alle copie di cui agli articoli 62-bis e 62-ter si applicano le disposizioni di cui agli articoli 50-bis e 51 del decreto legislativo 7 marzo 2005, n. 82. Art. 68-ter. - 1. Il notaio puo' rilasciare copie su supporto informatico degli atti da lui conservati, anche se l'originale e' stato formato su un supporto analogico. Parimenti, puo' rilasciare copie su supporto cartaceo, degli stessi atti, anche se informatici. 2. Quando l'uso di un determinato supporto non e' prescritto dalla legge o non e' altrimenti regolato, il notaio rilascia le copie degli atti da lui conservati sul supporto indicato dal richiedente. 3. Il notaio attesta la conformita' del documento informatico all'originale o alle copie apponendo la propria firma digitale.»;
- n) la rubrica del Capo IV del Titolo III della legge 16 febbraio 1913, n. 89, e' sostituita dalla seguente: «Capo IV - Degli atti che si rilasciano in originale, dell'autenticazione e del rilascio di copie di documenti.»;
- o) L'articolo 73 e' sostituito dal seguente: «Art. 73. - 1. Il notaio puo' attestare la conformita' all'originale di copie, eseguite su supporto informatico o cartaceo, di documenti formati su qualsiasi supporto ed a lui esibiti in originale o copia conforme.»;
- p) all'articolo 138, comma 2, cosi' come modificato dall'articolo 22 del decreto legislativo 1° agosto 2006, n. 249, le parole: «48 e 49» sono sostituite dalle seguenti: «48, 49 e 52-bis, comma 2.»;
- q) all'articolo 142, comma 1, lettera b), cosi' come modificato dall'articolo 24 del decreto legislativo 1° agosto 2006, n. 249, dopo le parole: «lettere b), c), d)» sono inserite le seguenti: «o nell'articolo 52-bis, comma 2,».

## Art. 2. - Modifica al regio decreto-legge 23 ottobre 1924, n. 1737, convertito dalla legge 18 marzo 1926, n. 562

1. Al regio decreto-legge 23 ottobre 1924, n. 1737, convertito dalla legge 18 marzo 1926, n. 562, dopo l'articolo 23 e' inserito il seguente: «Art. 23-bis. - 1. Per gli atti pubblici e le scritture private autenticate informatiche, le annotazioni di cui all'articolo 23 e le altre annotazioni previste dalla legge sono eseguite secondo le modalita' determinate ai sensi dell'articolo 68-bis, comma 1, della legge 16 febbraio 1913, n. 89.».

## Art. 3. - Modifica alla legge 3 agosto 1949, n. 577

1. Alla legge 3 agosto 1949, n. 577, dopo l'articolo 2 e' inserito il seguente: «Art. 2-bis. - 1. Il Consiglio nazionale del notariato svolge l'attivita' di certificatore della firma rilasciata al notaio per l'esercizio delle sue funzioni.».

## Art. 4. - Disposizioni di attuazione

1. Con uno o piu' decreti del Ministro della giustizia aventi natura non regolamentare sono stabilite la data in cui acquistano efficacia le disposizioni di cui all'articolo 66-bis, comma 1, della legge 16 febbraio 1913, n. 89, nonche' la data di inizio dell'operativita' della struttura di cui all'articolo 68-bis, comma 1, e quella in cui acquista efficacia l'obbligo di conservazione delle copie di cui all'articolo 62-ter della medesima legge.

